% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qDEAC.R
\name{A2SM}
\alias{A2SM}
\title{A2SM: Convert a matrix A to sparse matrix form}
\usage{
A2SM(A, SMM = "CRI", ZINDEX = F, eps = .Machine$double.eps, NA_flag = (-1e+06))
}
\arguments{
\item{A}{The matrix A.}

\item{SMM}{Sparse matrix method with SMM='A',CRI','RCI','CMO', or 'RMO'}

\item{ZINDEX}{T = Use zero indexing or F = Use one indexing.}

\item{eps}{Value to use in non-zero test.}

\item{NAflag}{Number to uses as NA flag}
}
\value{
A list object containing the matrix components:

nnz     = the number of non-zero elements in ra.

nr      = the number of rows in matrix A.

nc      = the number of columns in matrix A.

ia      = the row index.

ja      = the column index.

ra      = the non-zero coefficients in A

rnames  = matrix row names -- may be  ""

cnames  = matrix column names -- may be ""

SMM     = the sparse matrix type.

ZINDEX with T = Use zero indexing or F = Use one indexing.
}
\description{
A2SM: Convert a matrix A to sparse matrix form
}
\examples{
\dontrun{
(A = matrix(c(1,0,0,2,0,3,0,0,0,5,0,6),3,4,byrow=T))
(SM1 = A2SM(A,SMM='CMO',ZINDEX=T))
(SM2=SM2SM(SM1,SMM='CRI',ZINDEX=F))
SM2A(SM1)
SM2A(SM2)

(A = matrix(c(1,0,0,2,0,3,0,0,0,5,0,6),3,4,byrow=T)); A[2,3]=NA; A
(ASM = A2SM(A,SMM='CMO',ZINDEX=T)); SM2A(ASM)
(ASM2 = SM2SM(ASM,SMM2='CRI',ZINDEX2=T)); A ; (A2 = SM2A(SM2))

#clpAPI  documentation example
nr=5
nc=8
ra=c(3.0,5.6,1.0,2.0,1.1,1.0,-2.0,2.8,-1.0,1.0,1.0,-1.2,-1.0,1.9)
ia=c(0,4,0,1,1,2,0,3,0,4,2,3,0,4)
ja=c(0,2,4,6,8,10,11,12,14)
SMM='CMO'
ZINDEX=T
ASM=list(nr=nr,nc=nc,ra=ra,ia=ia,ja=ja,SMM=SMM,ZINDEX=ZINDEX)
(A=SM2A(ASM))
}
}
