% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qDEAC.R
\name{SM2SM}
\alias{SM2SM}
\title{SM2SM: Convert a sparse matrix form into a different sparse matrix form.}
\usage{
SM2SM(ASM, SMM2 = "CRI", ZINDEX2 = F, NA_flag = (-1e+06))
}
\arguments{
\item{ASM}{A sparse matrix object}

\item{SMM2}{sparse matrix method with SMM2 ='A','CRI','RCI','CMO',or'RMO'}

\item{ZINDEX2}{T = Use zero indexing or F = Use one indexing.}

\item{NAflag}{Number to uses as NA flag}
}
\value{
A list object containing the following sparse matrix components:

nnz    = the number of non-zero elements in ra.

nr     = the number of rows in matrix.

nc     = the number of columns in matrix.

ia     = the revised row index.

ja     = the revised column index.

rnames = row names  -- may be missing or ""

cnames = column names -- may be missing or ""

ra     = the revised non-zero coefficients in A

SMM    = the revised sparse matrix type.

ZINDEX = T or F for the revised sparse form.
}
\description{
ASM is a sparse matrix object containing:
nr = number of rows, nc = number of columns, ra = nonzero coeff,
 ia = row indices, ja = col indices, SMM = space matrix method,
 ZINDEX=use 0-indexing
}
\examples{
\dontrun{
(A = matrix(c(1,0,0,2,0,3,0,0,0,5,0,6),3,4,byrow=T))
(SM1 = A2SM(A,SMM='CMO',ZINDEX=T))
(SM2=SM2SM(SM1,SMM='CRI',ZINDEX=F))
SM2A(SM1)
SM2A(SM2)

(A = matrix(c(1,0,0,2,0,3,0,0,0,5,0,6),3,4,byrow=T)); A[2,3]=NA; A
(ASM = A2SM(A,SMM='CMO',ZINDEX=T)); SM2A(ASM)
(ASM2 = SM2SM(ASM,SMM2='CRI',ZINDEX2=T)); A ; (A2 = SM2A(SM2))

#clpAPI  documentation example
nr=5
nc=8
ra=c(3.0,5.6,1.0,2.0,1.1,1.0,-2.0,2.8,-1.0,1.0,1.0,-1.2,-1.0,1.9)
ia=c(0,4,0,1,1,2,0,3,0,4,2,3,0,4)
ja=c(0,2,4,6,8,10,11,12,14)
SMM='CMO'
ZINDEX=T
ASM=list(nr=nr,nc=nc,ra=ra,ia=ia,ja=ja,SMM=SMM,ZINDEX=ZINDEX)
(A=SM2A(ASM))
}
}
