% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qDEAC.R
\name{qDEAC}
\alias{qDEAC}
\title{qDEAC: Calling function for set of DEA and qDEA processes}
\usage{
qDEAC(
  X,
  Y,
  qout = 1/nrow(X),
  qoutS = qout,
  X0 = NULL,
  Y0 = NULL,
  DX0 = NULL,
  DY0 = NULL,
  orient = "out",
  RTS = "CRS",
  dmulist = NULL,
  nqiter = 1,
  nboot = 0,
  transform = T,
  mcells = 5,
  mlist = NULL,
  seedval = 1001,
  qtol = 1e-06,
  BIGM = 1e+09,
  eps = 1e-06,
  skipzprob = T,
  replaceA1 = F,
  baseqDEA = F,
  unbounded = (-1000),
  obj2test = 1e-04,
  replaceM = F,
  alpha = 0.05,
  betaq = 0.5,
  siglist = c(0.1, 0.05, 0.01),
  CILag = 1,
  printlog = T,
  prntmod = 100,
  printtxt = "",
  getproject = F,
  getbootpeers = F
)
}
\arguments{
\item{X}{Reference dmu's = ndmu x number of inputs input matrix.}

\item{Y}{Reference dmu's = ndmu x number of outputs output matrix.}

\item{qout}{Maximal proportion of dmu's allowed external to DEA hull.
Default = 1/ndmu}

\item{qoutS}{Proportion of external points to identify using qDEA slicing
(Atwood and Shaik 2020 EJOR)with qoutS <= qout. Default = qout}

\item{X0}{Inputs for set of ndmu0 dmu's to be processed. Default = X}

\item{Y0}{Outputs for set of ndmu0 dmu's to be processed. Default = Y}

\item{DX0}{Input directions for ndmu0 dmu's in X0 and Y0.
(Must be provideed if orient = 'ddea'). Default = NULL}

\item{DY0}{Output directions for ndmu0 dmu's in X0 and Y0.
(Must be provideed if orient = 'ddea') Default = NULL}

\item{orient}{Model orientation ('in','out','inout','oneone','ddea').
(!!If orient='ddea',DX0,and DY0 must be provided)
Default='out'}

\item{RTS}{Returns to scale.('CRS,'VRS,'DRS','IRS) Default 'CRS'.}

\item{dmulist}{Index vector of dmus in (X0,Y0) to process. NULL = process all.}

\item{nqiter}{Maximal number of qDEA iterations. Default = 1.}

\item{nboot}{Number of bootstrap replications. Default = 0.}

\item{transform}{Transform DDEA distance to traditional efficiency metrics
(input or output orientations only) Default = T}

\item{mcells}{Number of subsample sizes for bootstapping. Default = 5}

\item{mlist}{Optional list of user chosen subsample sizes. Default = NULL}

\item{seedval}{Seed value for random number generator - used in bootstapping.
Default = 1001.}

\item{qtol}{q search tolerance with iterative qDEA. Default = 1E-6}

\item{BIGM}{Default Big M in RHS of qDEA stage 2 process. Default = 1E9}

\item{eps}{Search tolerance in qDEA improvement tests. Default = 1E-6}

\item{skipzprob}{Skip qDEA if qout=0. Default = T.}

\item{replaceA1}{Put dmu0's data in first row of reference sets. Default = F}

\item{baseqDEA}{Use basic qDEA model from EJOR article. Default = F}

\item{unbounded}{qDEA reported as unbounded if obj<=unbounded. Default = (-1E3)}

\item{obj2test}{Convergance tol for objective in iterative qDEA.Default = 1E-4}

\item{replaceM}{Subsample with replacement in subsample bootstrap. Default = F}

\item{alpha}{Alpha level for Simar-Wilson(2011)subsample size selection
procedure. Default = 0.05}

\item{betaq}{qDEA convergence rate. 0.5 => "root n" convergence.}

\item{siglist}{Vector of user's desired confidence interval widths
Default = c(0.10, 0.05, 0.01)}

\item{CILag}{CILag level for Simar-Wilson (2011) subsample size
selection procedure. Default = 1}

\item{printlog}{Progress of DDEA dmu's solved when (X0,Y0) >1 dmus.}

\item{prntmod}{Print progress every prntmod dmus. Default=100.}

\item{printtxt}{Additional text to print with progress printlog.}

\item{getproject}{Compute projected values for dmu's in dmulist. Default=F}

\item{getbootpeers}{Pull and store peers for each bootstrapped solution.
Default = F}
}
\value{
'###################################################################'

A list of individual items and lists of addiitional/optional output

effvals   = vector of DDEA distances
      (efficiencies if transform=T and input or output orientation).

effvalsq  = vector of qDDEA distances
      (efficiencies if transform=T and input or output orientation).

distvals  = vector of DDEA distances

distvalsq = vector of qDEA distances

distMAT   = ndmu0 by 3 matrix with DDEA,qDDEA-S1,qDDEA-S2 distances.
'###########################################################################'

INPUT_DATA  = A list containing:

X       = reference dmu's = ndmu x number of inputs input matrix.

Y       = reference dmu's = ndmu x number of outputs output matrix.

X0      = inputs for set of ndmu0 dmu's processed.

Y0      = outputs for set of ndmu0 dmu's processed.

DX0     = input directions for ndmu0 dmu's processed.

DY0     = output directions for ndmu0 dmu's processed.

qout    = maximal proportion of dmu's allowed external to DEA hull.

qoutS   = proportion of external points to identify using qDEA slicing.

RTS     = returns to scale.

orient  = model orientation. ('ddea','in','out','inout','oneone')

baseqDEA = use basic qDEA model from EJOR article

dmulist0 =  DMU0 index in originally inputs X0,Y0,DX0,and DY0

'###################################################################'

BOOT_DATA  = A list containing:

effvals.bc   = vector of DDEA bias corrected distance or efficiency metrics
                       (efficiencies if transform=T and input or output orientation)

effvalsq.bc  = vector of qDEA bias corrected distaince or efficiency metrics
                       (efficiencies if transform=T and input or output orientation)

distvals.bc  = vector of bias corrected DDEA distances

distvalsq.bc = vector of bias corrected qDEA distances

mcells       = number of subsample sizes for bootstapping

mlist        = list of subsample sizes used in bootstraps

BOOTdmus     = matrix containing indexes of reference dmus chosen for each bootstrap

BOOT         = nboot by mcells by ndmu0 array of bootstrapped DDEA distances
                       (efficiencies if transform=T and input or output orientation)

BOOTS        = nboot by mcells by ndmu0 array of DDEA bootstrapped s-statistics
                       (statn = (m(n)/n)^beta (statm - statn)

BOOTs        = nboot by ndmu0 matrix of DDEA bootstrapped s-statistics
                       (at sample size chosen by Simar and Wilson (2011) suggested process)

BOOTq        = nboot by mcells by ndmu0 array of bootstrapped qDEA distances
                       (efficiencies if transform=T and input or output orientation)

BOOTSq       = nboot by mcells by ndmu0 array of qDEA bootstrapped s-statistics
                       (statn = (m(n)/n)^beta (statm - statn)

BOOTsq       = nboot by ndmu0 matrix of qDEA bootstrapped s-statistics
                       (at sample size chosen by Simar and Wilson (2011) suggested process

mpick        = length(ndmu0) index vector of DDEA bootstrap sample size chosen from mlist
                       using Simar and Wilson (2011) suggested sample size selection process

mpickq    = length(ndmu0) index vector of qDDEA bootstrap sample size chosen from mlist
                    using Simar and Wilson (2011) suggested sample size selection process

beta      = DDEA convergence rate indicated Simar-Wilson (2011)

betaq     = qDEA convergence rate indicated Atwood and Shaik(2020) = 0.5

siglist   = vector of user's desired confidence interval widths

CI        = ndmu0 by 2 by length(siglist) array of DDEA confidence intervals
                    (estimated using quantiles on bias corrcted "s" statistics)

CIq       = ndmu0 by 2 by length(siglist) array of qDEA confidence intervals
                    (estimated using quantiles on bias corrcted "s" statistics)

CIq_norm  = ndmu0 by 2 by length(siglist) array of qDEA confidence intervals
                    (estimated using sample mean and standard error of bootstrapped
                    "s" statistics and assuming normality) (Atwood and Shaik 2020)

'###################################################################'

PEER_DATA  = A list containing:

PEERS     = dataframe of DDEA peers and  projection weights for each dmu0

PEERSq    = dataframe of qDDEA-S2 peers and  projection weights each dmu0

DOUTq     = data frame indicating external dmus for each dmu's qDEA solution

BPEERS     = ndmu0 by mcells by (nIN+nOUT) by 2(dmu-z,zweight) array
                    of DDEA subsampled peers (dmu-z) and projection weights (z)
                    if(nboot>0&getbootpeers==T)

BPEERSq    = ndmu0 by mcells by (nIN+nOUT) by 2(dmu-z,zweight) array
                    of qDEA subsampled peers (dmu-z) and projection weights (z)
                    if(nboot>0&getbootpeers==T)

BPEERS1    = data.frame of DDEA subsampled peers and projection weights (z)
                    if(nboot>0&getbootpeers==T) for chosen subsample size
                    data.frame: nb = bootstrap rep, dmu0 = given dmu,
                    dmuz = reference dmu, z = reference dmu projection weight

BPEERS1q   = data.frame of qDEA subsampled peers and projection weights (z)
                    if(nboot>0&getbootpeers==T) for chosen subsample size
                    data.frame: nb = bootstrap rep, dmu0 = given dmu,
                    dmuz = reference dmu, z = reference dmu projection weight

'###################################################################'

PROJ_DATA  = Projected Values. A list containing:

X0HAT     = DDEA projected input levels  (if getproject=T)

Y0HAT     = DDEA projected output levels (if getproject=T)

X0HAT.bc  = bias corrected DDEA projected input levels
                    (if nboot>0 and getproject=T)
                    (if nboot>0 and getproject=T)   )

X0HATq    = qDEA projected input levels  (if getproject=T)

Y0HATq    = qDEA projected output levels (if getproject=T)

X0HATq.bc = bias corrected qDEA projected input levels
                    (if nboot>0 and getproject=T)

Y0HATq.bc = bias corrected qDEA projected output levels
                    (if nboot>0 and getproject=T)   )

'###################################################################'

LP_DATA  = LP Models, data, and results. A list containing:

status    = ndmu0 by 3 matrix with LP status of DDEA,qDDEA-S1,qDDEA-S2

qhat      = proportion of dmu's external to hull in qDEA solution
                     (NA indicates qDEA for given DMU was unbounded)

qiter     = number of qDEA iterations completed.

PSOL      = ndmu0 by ? matrix with DDEA LP solutions for each dmu0

PSOLq1    = ndmu0 by ? matrix with qDDEA-S1 LP solutions for each dmu0

PSOLq2    = ndmu0 by ? matrix with qDDEA-S2 Lp solutions for each dmu0

RCOST     = ndmu0 by ? matrix of LP reduced costs for DDEA solutions

RCOSTq1   = ndmu0 by ? matrix of LP reduced costs for qDDEA-S1 solutions

RCOSTq2   = ndmu0 by ? matrix of LP reduced costs for qDDEA-S2 solutions

LPModels  = list of LP0, LP1, and LP2 LP objects from qDEAC_solve function
}
\description{
Note: Optional arguments in function call have default values of 'NULL'
}
\examples{
\dontrun{
############################################################################
# Examples from CST(2006): Cooper, W., Seiford, L., and Tone, K., 2006.
# Introduction to Data Envelopment Analysis and Its Uses.  Springer. NewYork.
###############################################################################
library(qDEAC)
###############################################################################
#CST One Input- One Output Example - Table 1.1
data(CST11)
CST11
attach(CST11)
(X = as.matrix(EMPLOYEES))
(Y = as.matrix(SALES_EJOR))
detach(CST11)
(qout=1/nrow(X))
sol=qDEAC(X,Y,RTS='crs',orient='in',qout=qout)
# DEA efficiency scores
sol$effvals
# qDEA input efficiency scores allowing one external point
sol$effvalsq
###############################################################################
#CST Two Input- One Output Example - Table 1.3
data(CST21)
CST21
attach(CST21)
(X = as.matrix(cbind(EMPLOYEES,FLOOR_AREA)))
(Y = as.matrix(SALES))
detach(CST21)
(qout=1/nrow(X))
sol=qDEAC(X,Y,RTS='crs',orient='in',qout=qout)
# DEA efficiency scores
sol$effvals
# qDEA input efficiency scores allowing one external point
sol$effvalsq
###############################################################################
#CST One Input- Two Output Example - Table 1.4
data(CST12)
CST12
attach(CST12)
(X = as.matrix(EMPLOYEES))
(Y = as.matrix(cbind(CUSTOMERS,SALES)))
detach(CST12)
(qout=1/nrow(X))
sol=qDEAC(X,Y,RTS='crs',orient='out',qout=qout)
# DEA efficiency scores
sol$effvals
# qDEA output efficiency scores allowing one external point
sol$effvalsq
###############################################################################
#CST Two Input- Two Output Example - Table 1.5
data(CST22)
CST22
attach(CST22)
(X = as.matrix(cbind(DOCTORS,NURSES)))
(Y = as.matrix(cbind(OUT_PATIENTS,IN_PATIENTS)))
detach(CST22)
(qout=1/nrow(X))
sol=qDEAC(X,Y,RTS='crs',orient='in',qout=qout)
# DEA efficiency scores - see table 1.6 CCR estimates
round(sol$effvals,2)
# qDEA efficiency scores allowing one external point
round(sol$effvalsq,2)
###############################################################################



###############################################################################
#Atwood-Shaik EJOR qDEA Examples
data(CST11)
CST11
(X = as.matrix(CST11$EMPLOYEES))
(Y = as.matrix(CST11$SALES_EJOR))
###############################################################################
# EJOR Efficiency Results Table 1 Input Orientation
tmpC1=qDEAC(X,Y,RTS='crs',orient='in',qout=1/8,getproject = T)
tmpC2=qDEAC(X,Y,RTS='crs',orient='in',qout=2/8,getproject = T)

# Table 1 Input Orientation
round(cbind(tmpC1$distvals,tmpC1$PROJ_DATA$X0HAT,tmpC1$PROJ_DATA$Y0HAT,
      tmpC1$distvalsq,tmpC1$PROJ_DATA$X0HATq,tmpC1$PROJ_DATA$Y0HATq,
      tmpC2$distvalsq,tmpC2$PROJ_DATA$X0HATq,tmpC2$PROJ_DATA$Y0HATq),3)
###############################################################################
# EJOR Efficiency Results Table 1 Output Orientation
tmpC3=qDEAC(X,Y,RTS='crs',orient='out',qout=1/8,getproject = T)
tmpC4=qDEAC(X,Y,RTS='crs',orient='out',qout=2/8,getproject = T)

# Table 1 Output Orientation
round(cbind(tmpC3$distvals,tmpC3$PROJ_DATA$X0HAT,tmpC3$PROJ_DATA$Y0HAT,
      tmpC3$distvalsq,tmpC3$PROJ_DATA$X0HATq,tmpC3$PROJ_DATA$Y0HATq,
      tmpC4$distvalsq,tmpC4$PROJ_DATA$X0HATq,tmpC4$PROJ_DATA$Y0HATq),3)
###############################################################################
# EJOR Efficiency Results Table 1 one-one Orientation
tmpC5=qDEAC(X,Y,RTS='crs',orient='oneone',qout=1/8,getproject = T)
tmpC6=qDEAC(X,Y,RTS='crs',orient='oneone',qout=2/8,getproject = T)

# Table 1 one-one Orientation
round(cbind(tmpC5$distvals,tmpC5$PROJ_DATA$X0HAT,tmpC5$PROJ_DATA$Y0HAT,
     tmpC5$distvalsq,tmpC5$PROJ_DATA$X0HATq,tmpC5$PROJ_DATA$Y0HATq,
     tmpC6$distvalsq,tmpC6$PROJ_DATA$X0HATq,tmpC6$PROJ_DATA$Y0HATq),3)
###############################################################################
}
}
