% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qDEAC.R
\name{qDEAC_solve}
\alias{qDEAC_solve}
\title{qDEAC_solve: Sets up LP objects and solves DDEA dual DEA and qDEA using clp_API
             !!!! Intended to be called from qDEAC function.!!!!
Note: ndmu=number of dmus in reference set, ndmu0 = number dmus to process.}
\usage{
qDEAC_solve(
  X,
  Y,
  qout = 0.1,
  qoutS = qout,
  X0,
  Y0,
  DX0,
  DY0,
  RTS = "CRS",
  nqiter = 1,
  qtol = 1e-06,
  BIGM = 1e+09,
  eps = 1e-06,
  skipzprob = T,
  unbounded = (-1000),
  obj2test = 1e-04,
  replaceA1 = F,
  baseqDEA = F,
  printlog = T,
  prntmod = 100,
  printtxt = "",
  dmulist0 = 1:nrow(X0)
)
}
\arguments{
\item{X}{Reference dmu's = ndmu x number of inputs input matrix.}

\item{Y}{Reference dmu's = ndmu x number of outputs output matrix.}

\item{qout}{Maximal proportion of dmu's allowed external to DEA hull.}

\item{qoutS}{Proportion of external points to identify using EJOR qDEA slicing.}

\item{X0}{Inputs for set of ndmu0 dmu's to be processed.}

\item{Y0}{Outputs for set of ndmu0 dmu's to be processed.}

\item{DX0}{Input directions for ndmu0 dmu's in X0 and Y0.}

\item{DY0}{Output directions for ndmu0 dmu's in X0 and Y0.}

\item{RTS}{Returns to scale default='CRS'  options are 'CRS,'VRS,'DRS','IRS.}

\item{nqiter}{Maximal number of qDEA iterations.}

\item{qtol}{q search tolerance with iterative qDEA.}

\item{BIGM}{Default Big M in RHS of qDEA stage 2 process.}

\item{eps}{Zero-test criterion. abs(x) > eps implies x!=0}

\item{skipzprob}{Skip qDEA if qout=0.}

\item{unbounded}{qDEA reported as unbounded if obj<=unbounded.}

\item{obj2test}{Convergence tol for objective in iterative qDEA.}

\item{replaceA1}{Put dmu0's data in first row of reference sets.}

\item{baseqDEA}{Use basic qDEA model from EJOR article}

\item{printlog}{Progress of dmu's solved when (X0,Y0) >1 dmus.}

\item{prntmod}{Print progress every prntmod dmus. default=100}

\item{printtxt}{Additional text to print with progress printlog.}

\item{dmulist0}{DMU0 index in originally inputs X0,Y0,DX0,and DY0}
}
\value{
A list containing the following components:

effvals   = ndmu0 by 3 matrix with DDEA,qDDEA-S1,qDDEA-S2 distances
                    (NA indicates qDEA for given DMU was unbounded)

qhat      = proportion of dmu's external to hull in qDEA solution
                    (NA indicates qDEA for given DMU was unbounded)

qiter     = number of qDEA iterations completed.

D2OUT     = data frame indicating qDEA external reference dmus

status    = ndmu0 by 3 matrix with LP status of DDEA,qDDEA-S1,qDDEA-S2

PSOL      = ndmu0 by ? matrix with DDEA (dual-side) solutions for each dmu0

PSOLq1    = ndmu0 by ? matrix with qDDEA-S1 solutions for each dmu0

PSOLq2    = ndmu0 by ? matrix with qDDEA-S2 solutions for each dmu0

PEERS     = dataframe of non-zero DDEA dmuz's and  projection weights for each dmu0

PEERSq    = dataframe of non-zero qDDEA-S2 dmuz's projection weights for each dmu0

RCOST     = ndmu0 by ? matrix of LP reduced costs for DDEA solutions

RCOSTq1   = ndmu0 by ? matrix of LP reduced costs for qDDEA-S1 solutions

RCOSTq2   = ndmu0 by ? matrix of LP reduced costs for qDDEA-S2 solutions

devstart  = LP index for column of first qDDEA-S1 LPM "deviation" value

devend    = LP index for column of last  qDDEA-S1 LPM "deviation" value

LP0       = DDEA LP object for last dmu0 processed

LP1       = qDDEA-S1 LP object for last dmu0 processed

LP2       = qDDEA-S2 LP object for last dmu0 processed
}
\description{
qDEAC_solve: Sets up LP objects and solves DDEA dual DEA and qDEA using clp_API
             !!!! Intended to be called from qDEAC function.!!!!
Note: ndmu=number of dmus in reference set, ndmu0 = number dmus to process.
}
